#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ------------
#| Change Log |
# ------------
# Rel 1: Initial release.
# Rel 2: Change the order in the menu

from gimpfu import *
import os

def toggle_paths_invis_all(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()

	for v in image.vectors:
		v.visible = 0
	
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_invis_all",
    "Toggle paths Invisible all",
    "Toggle paths Invisible all",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/3. Invisible all",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_invis_all
)

def toggle_vis_all(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()

	for v in image.vectors:
		v.visible = 1
	
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_vis_all",
    "Toggle paths Visible all",
    "Toggle paths Visible all",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/1. Visible all",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_vis_all
)

def toggle_paths_vis_above_active(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	invector_position = pdb.gimp_image_get_item_position(image,invector)

	for v in image.vectors:
		position = pdb.gimp_image_get_item_position(image,v)

		if position < invector_position:		# Visible above active
			v.visible = 1		
		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_vis_above_active",
    "Toggle paths Visible above active",
    "Toggle paths Visible above active",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/2. Visible above Active",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_vis_above_active
)
def toggle_paths_reverse_all(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()

	for v in image.vectors:
		v.visible = int(not(v.visible))		
		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_reverse_all",
    "Toggle paths Reverse all",
    "Toggle paths Reverse all",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/4. Reverse Visibility of all",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_reverse_all
)
def toggle_paths_reverse_above_active(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	invector_position = pdb.gimp_image_get_item_position(image,invector)
	for v in image.vectors:
		position = pdb.gimp_image_get_item_position(image,v)		
		if position < invector_position:
			v.visible = int(not(v.visible))		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_reverse_above_active",
    "Toggle paths Reverse above active",
    "Toggle paths Reverse above active",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/5. Reverse Visibility above Active",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_reverse_above_active
)

def toggle_paths_linked_all(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	for v in image.vectors:
		v.linked = 1		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_linked_all",
    "Toggle paths Linked all",
    "Toggle paths Linked all",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/6. Linked (chain) all",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_linked_all
)
def toggle_paths_non_linked_all(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	for v in image.vectors:
		v.linked = 0		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_non_linked_all",
    "Toggle paths Non Linked all",
    "Toggle paths Non Linked all",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/7, Non Linked (chain) all",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_non_linked_all
)
def toggle_paths_reverse_chain_above_active(image, invector):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	invector_position = pdb.gimp_image_get_item_position(image,invector)
	for v in image.vectors:
		position = pdb.gimp_image_get_item_position(image,v)		
		if position < invector_position:
			v.linked = int(not(v.linked))		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
    "python_fu_toggle_paths_reverse_chain_above_active",
    "Toggle paths Reverse Linked above Active",
    "Toggle paths Reverse Linked above Active",
    "MrQ",
    "GPL",
    "2019",
    "<Vectors>/ Switch paths on:/8. Reverse Chain above Active",
    "",
    [
	(PF_IMAGE, "image", "Input image", None),
	(PF_VECTORS, "invector", "Input path", None),
    ],
    [],
    toggle_paths_reverse_chain_above_active
)
main()